@@ -8,7 +8,7 @@ HTTPD=httpd-$HTTPD_VER
 #	postgresql-8.4.x
 #	re2c-0.12.2
 #PHP
-VERSION=5.2.16
+VERSION=5.2.17
 #VERSION=5.2.7RC4
 
 REL=P1
@@ -32,7 +32,7 @@ fi
 PAC_NAME=php-${VERSION}
 SRC_FILE=${PAC_NAME}.tar.bz2
 SRC_URI="http://jp.php.net/get/$SRC_FILE/from/this/mirror"
-SRC_URI=http://downloads.php.net/ilia/$SRC_FILE
+#SRC_URI=http://downloads.php.net/ilia/$SRC_FILE
 
 if [ "$PAT_VER" != "" ]; then
   PAT_FILE=suhosin-patch-${VERSION}-${PAT_VER}.patch.gz
@@ -70,7 +70,7 @@ if [ ! -f $SRC_DIR/$SRC_FILE ]; then
     mkdir -p $SRC_DIR
   fi
   echo $SRC_URI
-  ( cd $SRC_DIR; wget $SRC_URI )
+  ( cd $SRC_DIR; wget -O $SRC_FILE $SRC_URI )
 fi
 if [ "x$PAT_VER" != "x" ]; then
   if [ ! -f $SRC_DIR/$PAT_FILE ]; then
